﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Configuration;
using System.Web;

namespace UrlRewrite
{
    public class UrlRewriteConfig : ConfigurationSection
    {
        [ConfigurationProperty("enable", DefaultValue = false)]
        public bool Enable
        {
            get
            {
                return (bool)base["enable"];
            }
        }

        [ConfigurationProperty("suffix", DefaultValue = ".html")]
        public string Suffix
        {
            get
            {
                return (string)base["suffix"];
            }
        }


        [ConfigurationProperty("", IsDefaultCollection = true)]
        public RulesElectionCollection Rules
        {
            get
            {
                return (RulesElectionCollection)base[""];
            }
        }

    }

    public class UrlRewriteConfigRule : ConfigurationElement
    {
        [ConfigurationProperty("form")]
        public string Form
        {
            get
            {
                return (string)base["form"];
            }
        }
        [ConfigurationProperty("to")]
        public string To
        {
            get
            {
                return (string)base["to"];
            }
        }
        [ConfigurationProperty("query")]
        public string Query
        {
            get
            {
                return (string)base["query"];
            }
        }
    }

    public class RulesElectionCollection : ConfigurationElementCollection
    {
        protected override ConfigurationElement CreateNewElement()
        {
            return new UrlRewriteConfigRule();
        }

        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((UrlRewriteConfigRule)element).Form;
        }
    }

    public static class UrlRewriteConfigHelp
    {
        public static bool Enabled
        {
            get
            {
                UrlRewriteConfig section
                    = ConfigurationManager.GetSection("rulesGroup/rules")
                    as UrlRewriteConfig;
                if (section == null)
                {
                    return false;
                }
                return section.Enable;
            }
        }

        public static string Suffix
        {
            get
            {
                UrlRewriteConfig section
                    = ConfigurationManager.GetSection("rulesGroup/rules")
                    as UrlRewriteConfig;
                if (section == null)
                {
                    return ".html";
                }
                return section.Suffix;
            }
        }


        public static RulesElectionCollection Rules
        {
            get
            {
                UrlRewriteConfig section
                    = ConfigurationManager.GetSection("rulesGroup/rules")
                    as UrlRewriteConfig;
                if (section == null)
                {
                    throw new System.InvalidOperationException("未能获取rulesGroup/rules");
                }
                return section.Rules;
            }
        }

        public static string RewriteBase
        {
            get
            {
                string path = HttpContext.Current.Request.ApplicationPath;
                if (!path.EndsWith("/"))
                {
                    return path + "/";
                }

                return path;
            }
        }

    }

}
